@@ -42,7 +42,7 @@ class TextStructureClient(NamespacedClient):
         lines_to_sample: t.Optional[int] = None,
         quote: t.Optional[str] = None,
         should_trim_fields: t.Optional[bool] = None,
-        timeout: t.Optional[t.Union[int, str]] = None,
+        timeout: t.Optional[t.Union["t.Literal[-1]", "t.Literal[0]", str]] = None,
         timestamp_field: t.Optional[str] = None,
         timestamp_format: t.Optional[str] = None,
     ) -> ObjectApiResponse[t.Any]:
@@ -50,7 +50,7 @@ class TextStructureClient(NamespacedClient):
         Finds the structure of a text file. The text file must contain data that is suitable
         to be ingested into Elasticsearch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.2/find-structure.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/find-structure.html>`_
 
         :param text_files:
         :param charset: The text’s character set. It must be a character set that is
