@@ -42,7 +42,7 @@ class WatcherClient(NamespacedClient):
         """
         Acknowledges a watch, manually throttling the execution of the watch's actions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-ack-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-ack-watch.html>`_
 
         :param watch_id: Watch ID
         :param action_id: A comma-separated list of the action ids to be acked
@@ -84,7 +84,7 @@ class WatcherClient(NamespacedClient):
         """
         Activates a currently inactive watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-activate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-activate-watch.html>`_
 
         :param watch_id: Watch ID
         """
@@ -120,7 +120,7 @@ class WatcherClient(NamespacedClient):
         """
         Deactivates a currently active watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-deactivate-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-deactivate-watch.html>`_
 
         :param watch_id: Watch ID
         """
@@ -156,7 +156,7 @@ class WatcherClient(NamespacedClient):
         """
         Removes a watch from Watcher.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-delete-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-delete-watch.html>`_
 
         :param id: Watch ID
         """
@@ -210,7 +210,7 @@ class WatcherClient(NamespacedClient):
         """
         Forces the execution of a stored watch.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-execute-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-execute-watch.html>`_
 
         :param id: Identifier for the watch.
         :param action_modes: Determines how to handle the watch actions as part of the
@@ -285,7 +285,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves a watch by its ID.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-get-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-get-watch.html>`_
 
         :param id: Watch ID
         """
@@ -334,7 +334,7 @@ class WatcherClient(NamespacedClient):
         """
         Creates a new watch, or updates an existing one.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-put-watch.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-put-watch.html>`_
 
         :param id: Watch ID
         :param actions:
@@ -412,8 +412,8 @@ class WatcherClient(NamespacedClient):
         query: t.Optional[t.Mapping[str, t.Any]] = None,
         search_after: t.Optional[
             t.Union[
-                t.List[t.Union[None, float, int, str]],
-                t.Tuple[t.Union[None, float, int, str], ...],
+                t.List[t.Union[None, bool, float, int, str, t.Any]],
+                t.Tuple[t.Union[None, bool, float, int, str, t.Any], ...],
             ]
         ] = None,
         size: t.Optional[int] = None,
@@ -430,7 +430,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves stored watches.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-query-watches.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-query-watches.html>`_
 
         :param from_: The offset from the first result to fetch. Needs to be non-negative.
         :param query: Optional, query filter watches to be returned.
@@ -494,7 +494,7 @@ class WatcherClient(NamespacedClient):
         """
         Starts Watcher if it is not already running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-start.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-start.html>`_
         """
         __path = "/_watcher/_start"
         __query: t.Dict[str, t.Any] = {}
@@ -549,7 +549,7 @@ class WatcherClient(NamespacedClient):
         """
         Retrieves the current Watcher metrics.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-stats.html>`_
 
         :param metric: Defines which additional metrics are included in the response.
         :param emit_stacktraces: Defines whether stack traces are generated for each
@@ -589,7 +589,7 @@ class WatcherClient(NamespacedClient):
         """
         Stops Watcher if it is running.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.5/watcher-api-stop.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.6/watcher-api-stop.html>`_
         """
         __path = "/_watcher/_stop"
         __query: t.Dict[str, t.Any] = {}
